OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Mahaia",
    "Dashboard app" : "Mahaia aplikazioa",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "Hasi zure eguna informatuta\n\nNextcloud Dashboard zure eguneko abiapuntua da, erakutsiz\nzure hurrengo hitzorduen ikuspegi orokorra, premiazko mezu elektronikoak, txat mezuak,\nsarrerako txartelak, azken txioak eta askoz gehiago! Erabiltzaileek widget-ak gehi ditzakete\neta atzealdea aldatu nahieran.",
    "Customize" : "Pertsonalizatu",
    "Edit widgets" : "Editatu trepetak",
    "Get more widgets from the App Store" : "Lortu widget gehiago App Store-tik",
    "Change background image" : "Aldatu atzeko planoko irudia",
    "Weather service" : "Eguraldi zerbitzua",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Zure pribatutasunaren mesedetan, eguraldiaren datuak  Nextcloud zerbitzariak eskatzen ditu zure izenean, eguraldi zerbitzuak informazio pertsonalik ez jasotzeko.",
    "Weather data from Met.no" : "Met.no-ko eguraldiaren datuak",
    "geocoding with Nominatim" : "Geokodetzen Nominatim-ekin",
    "elevation data from OpenTopoData" : "Altitude datuak OpenTopoData-tik",
    "Weather" : "Eguraldia",
    "Status" : "Egoera",
    "Good morning" : "Egunon",
    "Good morning, {name}" : "Egunon, {name}",
    "Good afternoon" : "Arratsaldeon",
    "Good afternoon, {name}" : "Arratsaldeon, {name}",
    "Good evening" : "Gabon",
    "Good evening, {name}" : "Gabon, {name}",
    "Hello" : "Kaixo",
    "Hello, {name}" : "Kaixo, {name}",
    "Pick from Files" : "Hautatu fitxategietatik",
    "Default image" : "Irudi lehenetsia",
    "Plain background" : "Atzeko plano arrunta",
    "Insert from {productName}" : "Txertatu hemendik: {productName}",
    "Show something" : "Erakutsi zerbait",
    "Default images" : "Irudi lehenetsiak"
},
"nplurals=2; plural=(n != 1);");
